
From: Benoit Boissinot <benoit.boissinot@ens-lyon.org>

gcc-4 warns with 
include/linux/cpuset.h:21: warning: type qualifiers ignored on function
return type

cpuset_cpus_allowed is declared with const
extern const cpumask_t cpuset_cpus_allowed(const struct task_struct *p);

First const should be __attribute__((const)), but the gcc manual
explains that:

"Note that a function that has pointer arguments and examines the data
pointed to must not be declared const. Likewise, a function that calls a
non-const function usually must not be const. It does not make sense for
a const function to return void."

The following patch remove const from the function declaration.

Signed-off-by: Benoit Boissinot <benoit.boissinot@ens-lyon.org>
Acked-by: Paul Jackson <pj@sgi.com>
Signed-off-by: Andrew Morton <akpm@osdl.org>
---

 25-akpm/include/linux/cpuset.h |    2 +-
 25-akpm/kernel/cpuset.c        |    2 +-
 2 files changed, 2 insertions(+), 2 deletions(-)

diff -puN include/linux/cpuset.h~cpuset-remove-function-attribute-const include/linux/cpuset.h
--- 25/include/linux/cpuset.h~cpuset-remove-function-attribute-const	2005-04-10 15:09:34.000000000 -0700
+++ 25-akpm/include/linux/cpuset.h	2005-04-10 15:09:34.000000000 -0700
@@ -18,7 +18,7 @@ extern int cpuset_init(void);
 extern void cpuset_init_smp(void);
 extern void cpuset_fork(struct task_struct *p);
 extern void cpuset_exit(struct task_struct *p);
-extern const cpumask_t cpuset_cpus_allowed(const struct task_struct *p);
+extern cpumask_t cpuset_cpus_allowed(const struct task_struct *p);
 void cpuset_init_current_mems_allowed(void);
 void cpuset_update_current_mems_allowed(void);
 void cpuset_restrict_to_mems_allowed(unsigned long *nodes);
diff -puN kernel/cpuset.c~cpuset-remove-function-attribute-const kernel/cpuset.c
--- 25/kernel/cpuset.c~cpuset-remove-function-attribute-const	2005-04-10 15:09:34.000000000 -0700
+++ 25-akpm/kernel/cpuset.c	2005-04-10 15:09:34.000000000 -0700
@@ -1432,7 +1432,7 @@ void cpuset_exit(struct task_struct *tsk
  * tasks cpuset.
  **/
 
-const cpumask_t cpuset_cpus_allowed(const struct task_struct *tsk)
+cpumask_t cpuset_cpus_allowed(const struct task_struct *tsk)
 {
 	cpumask_t mask;
 
_
